# comic-get.pl - Utility for fetching comics from the internet
# Copyright (C) 2004-2006 Tommi Saviranta <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

package ComicGet::Files;

use strict;
use warnings FATAL => 'all';

use ComicGet::Config;


=item uri_to_file
Convert repository identifier to filename.

0: ID
r: Filename
=cut
sub id_to_file($) {
	$_ = shift;
	tr/\//_/;
	return $_;
}


=item get_base_filename
Get base filename and path to repository files.

0: Repository identifier
r: Filename
=cut
sub get_base_filename($) {
	my $id = shift;
	my $file = &id_to_file($id);

	&ComicGet::Config::read();
	return "$ComicGet::Config::home/${file}_";
}


=item md5sums
Get repo/md5sums filename.

0: Repository ID
r: Filename
=cut
sub md5sums($) {
	my $id = shift;
	my $base = &get_base_filename($id);
	return "${base}md5sums";
}


=item packages
Get repo/packages filename.

0: Repository ID
r: Filename
=cut
sub packages($) {
	my $id = shift;
	my $base = &get_base_filename($id);
	return "${base}Packages";
}


=item rules_md5sums
Get repo/rules_md5sums filename.

0: Repository ID
r: Filename
=cut
sub rules_md5sums($) {
	my $id = shift;
	my $base = &get_base_filename($id);
	return "${base}rules.md5sums";
}


=item rule
Get repo/rule filename.

0: Package
1: Language
r: Filename
=cut
sub rule($) {
	my ($name, $lang) = @_;
	&ComicGet::Config::read();
	my $olang = $lang;
	$olang =~ tr/[A-Z]/[a-z]/;
	return "$ComicGet::Config::home/${name}_${olang}.rule";
}


=item database
Get database filename.

r: Filename
=cut
sub database() {
	&ComicGet::Config::read();
	return "$ComicGet::Config::home/database";
}


=item index
Get index filename.

r: Filename
=cut
sub index() {
	&ComicGet::Config::read();
	return "$ComicGet::Config::home/index";
}


=item config
Get configuration file.

r: Filename
=cut
sub config() {
	return "$ComicGet::Config::home/config";
}


=item md5sums_uri
Get repo/md5sums URI.

0: Repository URI
r: URI
=cut
sub md5sums_uri($) {
	my $repo = shift;
	return "$repo/md5sums";
}


=item packages_uri
Get repo/packages URI.

0: Repository URI
r: URI
=cut
sub packages_uri($) {
	my $repo = shift;
	return "$repo/Packages";
}


=item rules_md5sums_uri
Get repo/rules_md5sums filename.

0: Repository URI
r: URI
=cut
sub rules_md5sums_uri($) {
	my $repo = shift;
	return "$repo/rules.md5sums";
}


=item rule_uri
Get rule URI.

0: Repository URI
1: Package
2: Language
r: URI
=cut
sub rule_uri($) {
	my ($repo, $name, $lang) = @_;
	my $olang = $lang;
	$olang =~ tr/[A-Z]/[a-z]/;
	return "$repo/${name}_$olang.rule";
}


1;
